# Introduction
:::{toctree}
:hidden:
getstarted/index.md
concepts/index.md
howtos/index.md
references/index.rst
community/index.md
:::

Ragas is a framework that helps you evaluate your Retrieval Augmented Generation (RAG) pipelines. RAG denotes a class of LLM applications that use external data to augment the LLM’s context. There are existing tools and frameworks that help you build these pipelines but evaluating it and quantifying your pipeline performance can be hard. This is where Ragas (RAG Assessment) comes in.


::::{grid} 2

:::{grid-item-card} 🚀 Get Started
:link: get-started
:link-type: ref

Learn the basics and become familiar with the Ragas metrics and how to evaluate
RAG pipelines with it, how to generate synthetic testsets to run evaluations
against and setting up online monitoring for your RAG apps.
:::

:::{grid-item-card} 📚 Core Concepts
:link: core-concepts
:link-type: ref

The high-level explainations for building a better understand about the
important topics such how to think about metrics-driven development, how the Ragas metrics work under the hood and synthetic dataset generation.
:::
:::{grid-item-card} 🛠️ How-to Guides
:link: how-to-guides
:link-type: ref

Practical guides to help you achieve a specific goals. Take a look at these
guides to learn how to use Ragas to solve real-world problems.
:::

:::{grid-item-card} 📖 References
:link: references
:link-type: ref

Technical descriptions of how Ragas classes and methods work.
:::
::::
